@@ -18,7 +18,7 @@ from django.shortcuts import render, redirect
 from django.contrib.auth.tokens import default_token_generator
 from django.utils.http import int_to_base36, base36_to_int
 
-from usertools.forms import UserCreationForm, UserInviteForm
+from usertools.forms import UserCreationForm, UserInviteForm, UserChangeForm
 
 
 # Mix in watson search, if available.
@@ -39,6 +39,8 @@ class UserAdmin(UserAdminBase, AdminBase):
     
     invite_confirm_form = AdminPasswordChangeForm
     
+    form = UserChangeForm
+    
     add_form_template = "admin/auth/user/add_form_usertools.html"
     
     invite_form_template = "admin/auth/user/invite_form.html"
@@ -308,6 +310,7 @@ class UserAdmin(UserAdminBase, AdminBase):
             user = User.objects.get(id=uid_int)
         except (ValueError, User.DoesNotExist):
             valid_link = False
+            user = None
         else:
             # Check the token.
             valid_link = default_token_generator.check_token(user, token)
